@@ -11,7 +11,7 @@
 import uuid
 
 from wtforms.fields import BooleanField, DecimalField, DateField, \
-    DateTimeField, FieldList, FileField, FloatField, FormField,\
+    DateTimeField, FieldList, FloatField, FileField, FormField,\
     HiddenField, IntegerField, PasswordField, RadioField, SelectField, \
     SelectMultipleField, SubmitField, TextField, TextAreaField
 
@@ -41,7 +41,7 @@ from flask import request, session, current_app
 
 from jinja2 import Markup
 
-from flaskext.wtf import recaptcha
+import recaptcha
 
 from recaptcha.fields import RecaptchaField
 from recaptcha.widgets import RecaptchaWidget
@@ -61,19 +61,19 @@ if _is_sqlalchemy:
 def _generate_csrf_token():
     return str(uuid.uuid4())
 
+
 class Form(BaseForm):
 
     csrf = fields.HiddenField()
 
     def __init__(self, formdata=None, *args, **kwargs):
 
-        if formdata is None:
-            formdata = request.form
+        csrf_enabled = kwargs.pop('csrf_enabled', None)
 
-        self.csrf_enabled = kwargs.pop('csrf_enabled', True)
-
-        self.csrf_enabled = self.csrf_enabled and \
-            current_app.config.get('CSRF_ENABLED', True)
+        if csrf_enabled is None:
+            csrf_enabled = current_app.config.get('CSRF_ENABLED', True)
+        
+        self.csrf_enabled = csrf_enabled
 
         self.csrf_session_key = kwargs.pop('csrf_session_key', None)
 
@@ -87,7 +87,26 @@ class Form(BaseForm):
             csrf_token = self.reset_csrf()
 
         super(Form, self).__init__(formdata, csrf=csrf_token, *args, **kwargs)
-    
+
+    def is_submitted(self):
+
+        return request and request.method in ("PUT", "POST")
+
+    def process(self, formdata=None, obj=None, **kwargs):
+
+        if self.is_submitted():
+        
+            if formdata is None:
+                formdata = request.form
+
+            if request.files:
+
+                for name, field in self._fields.iteritems():
+                    if isinstance(field, FileField) and name in request.files:
+                        field.file = request.files[name]
+
+        super(Form, self).process(formdata, obj, **kwargs)
+
     @property
     def csrf_token(self):
         """
@@ -120,6 +139,6 @@ class Form(BaseForm):
             raise ValidationError, "Missing or invalid CSRF token"
 
     def validate_on_submit(self):
-        return request.method in ("POST", "PUT") and self.validate()
+        return self.is_submitted() and self.validate()
     
 
